@@ -391,6 +391,42 @@ sub xhtml_tag
   return '<' . ref($self)->xhtml_element . $self->xhtml_attrs_string . ' />';
 }
 
+#
+# Lame start/end HTML fall-backs for lazy derived classes
+#
+
+sub start_html
+{
+  my($self) = shift;
+  my $html = $self->html;
+  $html =~ s{</\w+>\z}{};
+  return $html;
+}
+
+sub end_html
+{
+  my($self) = shift;
+  my $html = $self->html;
+  $html =~ m{</\w+>\z};
+  return $1 || '';
+}
+
+sub start_xhtml
+{
+  my($self) = shift;
+  my $xhtml = $self->xhtml;
+  $xhtml =~ s{</\w+>\z}{};
+  return $xhtml;
+}
+
+sub end_xhtml
+{
+  my($self) = shift;
+  my $xhtml = $self->xhtml;
+  $xhtml =~ m{</\w+>\z};
+  return $1 || '';
+}
+
 sub default_html_attr_value 
 {
   my($class) = shift;
@@ -854,7 +890,7 @@ Get or set an error string.
 
 =item B<escape_html [BOOL]>
 
-This flag may be used by other methods to decide whether or not to escape HTML.  It is set to true by default.  The only method in L<Rose::HTML::Object> that references it is C<html_error>.  All other HTML is escaped as appropriate regardless of the C<escape_html> setting (e.g. the text returned by C<html_attrs_string> always has its attribute values escaped).  Subclasses may consult this flag for similar purposes (which they must document, of course).
+This flag may be used by other methods to decide whether or not to escape HTML.  It is set to true by default.  The only method in L<Rose::HTML::Object> that references it is L<html_error|/html_error>.  All other HTML is escaped as appropriate regardless of the L<escape_html|/escape_html> setting (e.g. the text returned by C<html_attrs_string> always has its attribute values escaped).  Subclasses may consult this flag for similar purposes (which they must document, of course).
 
 =item B<html>
 
@@ -946,7 +982,7 @@ Returns the error text, if any, as a snippet of HTML that looks like this:
 
     <span class="error">Error text goes here</span>
 
-If the C<escape_html> flag is set to true (the default), then the error text has any HTML in it escaped.
+If the L<escape_html|/escape_html> flag is set to true (the default), then the error text has any HTML in it escaped.
 
 =item B<html_tag>
 
@@ -960,6 +996,14 @@ If set to true, HTML attribute arguments to C<html_attr> and C<html_attr_hook> w
 
 A synonym for L<xhtml_tag()|/xhtml_tag>.
 
+=item B<xhtml_error>
+
+Returns the error text, if any, as a snippet of XHTML that looks like this:
+
+    <span class="error">Error text goes here</span>
+
+If the L<escape_html|/escape_html> flag is set to true (the default), then the error text has any HTML in it escaped.
+
 =item B<xhtml_tag>
 
 Serializes the object as an XHTML tag.  In other words, it is the concatenation of the strings returned by L<xhtml_element()|/xhtml_element> and L<xhtml_attrs_string()|/xhtml_attrs_string>, wrapped with the appropriate angled brackets and forward slash character.
